==> deepin-fcitxconfigtool-plugin_4.2.54.orig.tar.xz: deepin-fcitxconfigtool-plugin-4.2.54/translations/deepin-fcitxconfigtool-plugin_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>Fcitx::AdvancedSettingWidget</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="104"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="107"/>
        <source>Add-ons</source>
        <translation>Vključki</translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="241"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
</context>
<context>
    <name>FcitxConfigPlugin</name>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="69"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="81"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
        <source>Input Methods</source>
        <translation>Načini vnosa</translation>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="75"/>
        <source>Keyboard and Language</source>
        <translation>Tipkovnica in jezik</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <source>Manage Input Methods</source>
        <translation>Upravljanje načinov vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <source>Switch input methods</source>
        <translation>Zamenjaj način vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <source>Switch to the first input method</source>
        <translation>Preklopi na prvi način vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <source>Advanced Settings</source>
        <translation>Napredne nastavitve</translation>
    </message>
</context>
<context>
    <name>FcitxSettingsHead</name>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="51"/>
        <location filename="../src/widgets/settingshead.cpp" line="135"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="137"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>IMAddWindow</name>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="62"/>
        <source>Add Input Method</source>
        <translation>Dodaj način vnosa</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="70"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="80"/>
        <source>Find more in App Store</source>
        <translation>Najdi več v Trgovini</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="86"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>IMSettingWindow</name>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="115"/>
        <source>Switch input methods</source>
        <translation>Zamenjaj način vnosa</translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="119"/>
        <source>Switch to the first input method</source>
        <translation>Preklopi na prvi način vnosa</translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
        <location filename="../src/window/imsettingwindow.cpp" line="124"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzeto</translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="128"/>
        <source>Advanced Settings</source>
        <translation>Napredne nastavitve</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="138"/>
        <source>Manage Input Methods</source>
        <translation>Upravljanje načinov vnosa</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="148"/>
        <source>Shortcuts</source>
        <translation>Bljižnice</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="165"/>
        <source>Add Input Method</source>
        <translation type="unfinished">Dodaj način vnosa</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="606"/>
        <location filename="../src/window/advancedsettingwidget.cpp" line="658"/>
        <source>None</source>
        <translation>brez</translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="596"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="47"/>
        <location filename="../src/widgets/keysettingsitem.cpp" line="166"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="53"/>
        <source>Enter a new shortcut</source>
        <translation>Vnesite novo bližnjico</translation>
    </message>
</context>
</TS>

==> deepin-fcitxconfigtool-plugin_4.2.55.orig.tar.xz: deepin-fcitxconfigtool-plugin-4.2.55/translations/deepin-fcitxconfigtool-plugin_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>Fcitx::AdvancedSettingWidget</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="105"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="108"/>
        <source>Add-ons</source>
        <translation>Vključki</translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="391"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
</context>
<context>
    <name>FcitxConfigPlugin</name>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="69"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="81"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
        <source>Input Methods</source>
        <translation>Načini vnosa</translation>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="75"/>
        <source>Keyboard and Language</source>
        <translation>Tipkovnica in jezik</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <source>Manage Input Methods</source>
        <translation>Upravljanje načinov vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <source>Switch input methods</source>
        <translation>Zamenjaj način vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <source>Switch to the first input method</source>
        <translation>Preklopi na prvi način vnosa</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <source>Advanced Settings</source>
        <translation>Napredne nastavitve</translation>
    </message>
</context>
<context>
    <name>FcitxSettingsHead</name>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="51"/>
        <location filename="../src/widgets/settingshead.cpp" line="135"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="137"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
</context>
<context>
    <name>IMAddWindow</name>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="62"/>
        <source>Add Input Method</source>
        <translation>Dodaj način vnosa</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="70"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="80"/>
        <source>Find more in App Store</source>
        <translation>Najdi več v Trgovini</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="86"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>IMSettingWindow</name>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="115"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="119"/>
        <source>Switch between the current/first input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="122"/>
        <location filename="../src/window/imsettingwindow.cpp" line="125"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzeto</translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="129"/>
        <source>Advanced Settings</source>
        <translation>Napredne nastavitve</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="139"/>
        <source>Manage Input Methods</source>
        <translation>Upravljanje načinov vnosa</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="149"/>
        <source>Shortcuts</source>
        <translation>Bljižnice</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="166"/>
        <source>Add Input Method</source>
        <translation>Dodaj način vnosa</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="585"/>
        <location filename="../src/window/advancedsettingwidget.cpp" line="637"/>
        <source>None</source>
        <translation>brez</translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="599"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="47"/>
        <location filename="../src/widgets/keysettingsitem.cpp" line="166"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="53"/>
        <source>Enter a new shortcut</source>
        <translation>Vnesite novo bližnjico</translation>
    </message>
</context>
</TS>
